@@ -5,13 +5,13 @@ Events API and streaming real-time events. It includes automatic retry logic,
 rate limiting, and credential handling.
 """
 
-import asyncio
 import json
 import logging
 from collections.abc import AsyncIterator
 from http import HTTPStatus
 from types import TracebackType
-from typing import Any, ClassVar, Self
+from typing import Any, Self
+from urllib.parse import quote
 
 from aiohttp import ClientSession, ClientTimeout
 from aiohttp_retry import ExponentialRetry, RetryClient
@@ -24,6 +24,7 @@ from .constants import (
     CLOUDFLARE_ERROR_CODES,
     RATE_LIMIT_MAX_RATE,
     RATE_LIMIT_TIME_PERIOD,
+    SESSION_TIMEOUT_BUFFER,
     TESTBED_URL,
     TIMEOUT_ERROR_INDICATOR,
     TOKEN_MASK_LENGTH,
@@ -42,6 +43,11 @@ class EventClient:
     and secure credential handling. Use as an async context manager or iterate
     directly for continuous event streaming.
 
+    Rate Limiting:
+        Each client instance has its own rate limiter (2000 requests per 60 seconds)
+        by default. To share rate limiting across multiple clients, pass the same
+        AsyncLimiter instance to the `rate_limiter` parameter.
+
     Attributes:
         username: Chaturbate username for authentication.
         token: Authentication token with Events API scope.
@@ -52,15 +58,13 @@ class EventClient:
         retry_client: Retry-enabled HTTP client wrapper.
     """
 
-    _rate_limiters: ClassVar[dict[str, AsyncLimiter]] = {}
-    """Shared rate limiters per username to handle event loop reuse."""
-
     def __init__(
         self,
         username: str,
         token: str,
         *,
         config: EventClientConfig | None = None,
+        rate_limiter: AsyncLimiter | None = None,
     ) -> None:
         """Initialize the EventClient with credentials and connection settings.
 
@@ -68,19 +72,21 @@ class EventClient:
             username: Chaturbate username for authentication.
             token: Authentication token with Events API scope.
             config: Configuration object with client settings. If None, uses defaults.
+            rate_limiter: Optional AsyncLimiter instance for rate limiting. If None,
+                creates a new limiter with default settings (2000 requests per 60 seconds).
 
         Raises:
-            ValueError: If username or token is empty or contains only whitespace.
+            AuthError: If username or token is empty or contains only whitespace.
         """
-        if not username.strip():
-            msg = "Username cannot be empty"
-            raise ValueError(msg)
-        if not token.strip():
-            msg = "Token cannot be empty"
-            raise ValueError(msg)
+        if not username or username != username.strip():
+            msg = "Username cannot be empty or contain leading/trailing whitespace"
+            raise AuthError(msg)
+        if not token or token != token.strip():
+            msg = "Token cannot be empty or contain leading/trailing whitespace"
+            raise AuthError(msg)
 
-        self.username = username.strip()
-        self.token = token.strip()
+        self.username = username
+        self.token = token
 
         self.config = config if config is not None else EventClientConfig()
         self.timeout = self.config.timeout
@@ -88,13 +94,10 @@ class EventClient:
         self.session: ClientSession | None = None
         self.retry_client: RetryClient | None = None
         self._next_url: str | None = None
-        if username not in EventClient._rate_limiters:
-            EventClient._rate_limiters[username] = AsyncLimiter(
-                max_rate=RATE_LIMIT_MAX_RATE, time_period=RATE_LIMIT_TIME_PERIOD
-            )
-        self._rate_limiter = EventClient._rate_limiters[username]
-        self._closed = False
-        self._lock = asyncio.Lock()
+        self._rate_limiter = rate_limiter or AsyncLimiter(
+            max_rate=RATE_LIMIT_MAX_RATE,
+            time_period=RATE_LIMIT_TIME_PERIOD,
+        )
 
         self._retry_options = ExponentialRetry(
             attempts=self.config.retry_attempts,
@@ -144,21 +147,30 @@ class EventClient:
         Returns:
             The URL with the authentication token masked for safe logging.
         """
-        return url.replace(self.token, self._mask_token(self.token))
+        masked = self._mask_token(self.token)
+        return url.replace(self.token, masked).replace(quote(self.token, safe=""), masked)
 
     async def __aenter__(self) -> Self:
         """Initialize HTTP session for async context manager.
 
         Returns:
             The EventClient instance with an active HTTP session.
+
+        Raises:
+            EventsError: If session initialization fails.
         """
-        if self.session is None:
-            self.session = ClientSession(
-                timeout=ClientTimeout(total=self.timeout + 5),
-            )
-            self.retry_client = RetryClient(
-                client_session=self.session, retry_options=self._retry_options
-            )
+        try:
+            if self.session is None:
+                self.session = ClientSession(
+                    timeout=ClientTimeout(total=self.timeout + SESSION_TIMEOUT_BUFFER),
+                )
+                self.retry_client = RetryClient(
+                    client_session=self.session, retry_options=self._retry_options
+                )
+        except Exception as e:
+            await self.close()
+            msg = "Failed to initialize HTTP session"
+            raise EventsError(msg) from e
         return self
 
     async def __aexit__(
@@ -184,25 +196,33 @@ class EventClient:
         """
         return self._next_url or URL_TEMPLATE.format(
             base_url=self.base_url,
-            username=self.username,
-            token=self.token,
+            username=quote(self.username, safe=""),
+            token=quote(self.token, safe=""),
             timeout=self.timeout,
         )
 
-    def _extract_and_update_next_url(self, text: str) -> bool:
-        """Extract nextUrl from timeout response and update internal state.
+    def _extract_next_url(self, text: str) -> str | None:
+        """Extract nextUrl from timeout error response and update internal state.
 
         Args:
             text: The response text containing potential error data with nextUrl.
 
         Returns:
-            True if nextUrl was found and updated, False otherwise.
+            The extracted nextUrl if present and updated, otherwise None.
         """
-        if next_url := self._extract_next_url(text):
+        try:
+            error_data = json.loads(text)
+        except json.JSONDecodeError:
+            logger.warning("Failed to parse error response for nextUrl extraction")
+            return None
+
+        if TIMEOUT_ERROR_INDICATOR in error_data.get("status", "").lower() and (
+            next_url := error_data.get("nextUrl")
+        ):
             logger.debug("Received nextUrl from timeout response")
             self._next_url = next_url
-            return True
-        return False
+            return str(next_url)
+        return None
 
     def _parse_response_data(self, resp_data: dict[str, Any]) -> list[Event]:
         """Parse API response data into Event objects.
@@ -215,11 +235,12 @@ class EventClient:
         """
         self._next_url = resp_data["nextUrl"]
         events = [Event.model_validate(item) for item in resp_data.get("events", [])]
-        logger.debug(
-            "Received %d events",
-            len(events),
-            extra={"event_types": [event.type.value for event in events[:3]]} if events else {},
-        )
+        if events:
+            logger.debug(
+                "Received %d events",
+                len(events),
+                extra={"event_types": [event.type.value for event in events[:3]]},
+            )
         return events
 
     async def _make_request(self, url: str) -> tuple[int, str]:
@@ -265,7 +286,7 @@ class EventClient:
             msg = f"Authentication failed for {self.username}"
             raise AuthError(msg)
 
-        if status == HTTPStatus.BAD_REQUEST and self._extract_and_update_next_url(text):
+        if status == HTTPStatus.BAD_REQUEST and self._extract_next_url(text):
             return False
 
         if status != HTTPStatus.OK:
@@ -325,32 +346,6 @@ class EventClient:
         data = self._parse_json_response(text)
         return self._parse_response_data(data)
 
-    @staticmethod
-    def _extract_next_url(text: str) -> str | None:
-        """Extract nextUrl from timeout error response.
-
-        Args:
-            text: The response text containing potential error data with nextUrl.
-
-        Returns:
-            The extracted nextUrl string if present in a timeout error response,
-            otherwise None.
-
-        Note:
-            JSON parsing errors are silently ignored and return None, as this
-            method is used for error recovery and should not raise exceptions.
-        """
-        try:
-            error_data = json.loads(text)
-        except json.JSONDecodeError:
-            logger.debug("Failed to parse error response for nextUrl extraction")
-            return None
-
-        if TIMEOUT_ERROR_INDICATOR in error_data.get("status", "").lower():
-            next_url = error_data.get("nextUrl")
-            return str(next_url) if next_url else None
-        return None
-
     async def _poll_continuously(self) -> AsyncIterator[Event]:
         """Continuously poll the API and yield events as they arrive.
 
@@ -380,14 +375,10 @@ class EventClient:
         Safely closes all active connections and cleans up resources.
         Can be called multiple times safely.
         """
-        async with self._lock:
-            if self._closed:
-                return
-            self._closed = True
-            if self.retry_client:
-                await self.retry_client.close()
-                self.retry_client = None
-            if self.session:
-                await self.session.close()
-                self.session = None
-            self._next_url = None
+        if self.retry_client:
+            await self.retry_client.close()
+            self.retry_client = None
+        if self.session:
+            await self.session.close()
+            self.session = None
+        self._next_url = None
