@@ -1,6 +1,5 @@
 """Exception classes for the Chaturbate Events client."""
 
-from .constants import RESPONSE_PREVIEW_LENGTH
 from .models import EventType
 
 
@@ -12,7 +11,6 @@ class EventsError(Exception):
     text when available.
 
     Attributes:
-        message: The error message describing what went wrong.
         status_code: HTTP status code from the failed request, if available.
         response_text: Raw response text from the API, if available.
     """
@@ -32,7 +30,6 @@ class EventsError(Exception):
             response_text: Raw response text from the API, if available.
         """
         super().__init__(message)
-        self.message = message
         self.status_code = status_code
         self.response_text = response_text
 
@@ -43,26 +40,20 @@ class EventsError(Exception):
             The error message, optionally including the status code.
         """
         if self.status_code is not None:
-            return f"{self.message} (HTTP {self.status_code})"
-        return self.message
+            return f"{super().__str__()} (HTTP {self.status_code})"
+        return super().__str__()
 
     def __repr__(self) -> str:
-        """Return detailed string representation of the error.
+        """Return detailed string representation for debugging.
 
         Returns:
-            A string representation including the error message, status code,
-            and a preview of the response text if available.
+            A string showing the class name and all error attributes.
         """
-        parts = [f"message='{self.message}'"]
+        parts = [f"message={self.args[0]!r}"]
         if self.status_code is not None:
             parts.append(f"status_code={self.status_code}")
-        if self.response_text:
-            preview = (
-                self.response_text[:RESPONSE_PREVIEW_LENGTH] + "..."
-                if len(self.response_text) > RESPONSE_PREVIEW_LENGTH
-                else self.response_text
-            )
-            parts.append(f"response_text='{preview}'")
+        if self.response_text is not None:
+            parts.append(f"response_text={self.response_text[:50]!r}...")
         return f"{self.__class__.__name__}({', '.join(parts)})"
 
 
@@ -88,7 +79,6 @@ class RouterError(Exception):
     via exception chaining.
 
     Attributes:
-        message: Description of what went wrong in the handler.
         event_type: The type of event being processed when the error occurred.
         handler_name: The name of the handler function where the error occurred.
 
@@ -112,7 +102,6 @@ class RouterError(Exception):
             handler_name: The name of the handler function where the error occurred.
         """
         super().__init__(message)
-        self.message = message
         self.event_type = event_type
         self.handler_name = handler_name
 
@@ -122,7 +111,7 @@ class RouterError(Exception):
         Returns:
             The error message, optionally including event type and handler name.
         """
-        parts = [self.message]
+        parts = [super().__str__()]
         if self.event_type is not None:
             parts.append(f"event_type={self.event_type.value}")
         if self.handler_name is not None:
@@ -130,15 +119,14 @@ class RouterError(Exception):
         return " | ".join(parts)
 
     def __repr__(self) -> str:
-        """Return detailed string representation of the router error.
+        """Return detailed string representation for debugging.
 
         Returns:
-            A string representation including the error message, event type,
-            and handler name if available.
+            A string showing the class name and all error attributes.
         """
-        parts = [f"message='{self.message}'"]
+        parts = [f"message={self.args[0]!r}"]
         if self.event_type is not None:
-            parts.append(f"event_type={self.event_type.value}")
+            parts.append(f"event_type={self.event_type!r}")
         if self.handler_name is not None:
-            parts.append(f"handler_name='{self.handler_name}'")
+            parts.append(f"handler_name={self.handler_name!r}")
         return f"{self.__class__.__name__}({', '.join(parts)})"
