@@ -14,6 +14,12 @@ class BaseEventModel(BaseModel):
     Provides common Pydantic configuration including automatic snake_case
     conversion from API camelCase, frozen instances for immutability, and
     extra field ignoring for forward compatibility.
+
+    Note:
+        The `extra="ignore"` configuration allows the library to handle new fields
+        added to the API without breaking. However, this also means typos in field
+        names will be silently ignored during development. Always verify field names
+        against the API documentation.
     """
 
     model_config = ConfigDict(
@@ -128,7 +134,7 @@ class Message(BaseEventModel):
             True if this is a private message (has both from_user and to_user),
             False if this is a public chat message.
         """
-        return bool(self.from_user and self.to_user)
+        return self.from_user is not None and self.to_user is not None
 
 
 class Tip(BaseEventModel):
@@ -172,6 +178,12 @@ class Event(BaseEventModel):
     through properties, ensuring type safety while maintaining flexibility for
     future API changes.
 
+    Important:
+        Event properties return `None` when accessed on incompatible event types.
+        For example, `event.tip` returns `None` for non-TIP events. Always check
+        the event type or verify the property is not `None` before accessing its
+        attributes.
+
     Attributes:
         type: The type of event (e.g., TIP, CHAT_MESSAGE, USER_ENTER).
         id: Unique identifier for this event.
@@ -189,7 +201,7 @@ class Event(BaseEventModel):
         Returns:
             User object if user data is present in the event, otherwise None.
         """
-        if user_data := self.data.get("user"):
+        if (user_data := self.data.get("user")) is not None:
             return User.model_validate(user_data)
         return None
 
@@ -200,7 +212,7 @@ class Event(BaseEventModel):
         Returns:
             Tip object if this is a tip event with tip data, otherwise None.
         """
-        if self.type == EventType.TIP and (tip_data := self.data.get("tip")):
+        if self.type == EventType.TIP and (tip_data := self.data.get("tip")) is not None:
             return Tip.model_validate(tip_data)
         return None
 
@@ -212,8 +224,9 @@ class Event(BaseEventModel):
             Message object if this is a message event with message data,
             otherwise None.
         """
-        if self.type in {EventType.CHAT_MESSAGE, EventType.PRIVATE_MESSAGE} and (
-            message_data := self.data.get("message")
+        if (
+            self.type in {EventType.CHAT_MESSAGE, EventType.PRIVATE_MESSAGE}
+            and (message_data := self.data.get("message")) is not None
         ):
             return Message.model_validate(message_data)
         return None
