@@ -2,20 +2,36 @@
 
 import logging
 from collections import defaultdict
-from collections.abc import Awaitable, Callable
+from collections.abc import Callable
+from typing import Protocol
 
 from .exceptions import RouterError
 from .models import Event, EventType
 
 logger = logging.getLogger(__name__)
 
-EventHandler = Callable[[Event], Awaitable[None]]
-"""Type alias for async event handler functions.
 
-Event handlers are async functions that accept an Event and return None.
-They are registered using the EventRouter.on() or EventRouter.on_any()
-decorators and are called sequentially when events are dispatched.
-"""
+class EventHandler(Protocol):  # pylint: disable=too-few-public-methods
+    """Protocol for async event handler functions.
+
+    Event handlers are async callables that accept an Event and return None.
+    They are registered using the EventRouter.on() or EventRouter.on_any()
+    decorators and are called sequentially when events are dispatched.
+
+    Example:
+        .. code-block:: python
+
+            async def my_handler(event: Event) -> None:
+                print(f"Received event: {event.type}")
+    """
+
+    async def __call__(self, event: Event) -> None:
+        """Handle an event.
+
+        Args:
+            event: The event to handle.
+        """
+        ...  # pylint: disable=unnecessary-ellipsis
 
 
 class EventRouter:
@@ -87,17 +103,19 @@ class EventRouter:
     async def dispatch(self, event: Event) -> None:
         """Dispatch an event to all matching registered handlers.
 
-        All registered handlers are awaited sequentially. If any handler raises
-        an exception, it is caught, logged, and re-raised as a RouterError with
-        context about the failure. The original exception is preserved via
-        exception chaining.
+        All registered handlers are awaited sequentially. Handlers for the
+        specific event type are called after any handlers registered for all
+        event types. All handlers are attempted even if one fails. If any
+        handlers raise exceptions, a RouterError is raised after all handlers
+        have been attempted.
 
         Args:
             event: The event to dispatch.
 
         Raises:
-            RouterError: If any handler raises an exception. The original exception
-                is preserved as the cause (__cause__) for full traceback access.
+            RouterError: If any handler raises an exception during execution.
+                The first exception is included as the cause, and details of all
+                failed handlers are logged.
         """
         all_handlers = [
             *self._handlers[None],
@@ -113,19 +131,31 @@ class EventRouter:
             len(all_handlers),
         )
 
+        errors: list[tuple[str, Exception]] = []
         for handler in all_handlers:
             try:
                 await handler(event)
-            except Exception as e:
+            except Exception as e:  # pylint: disable=broad-except
                 handler_name = getattr(handler, "__name__", repr(handler))
+                errors.append((handler_name, e))
                 logger.exception(
-                    "Error in handler %s for event type %s",
+                    "Handler %s failed for event type %s",
                     handler_name,
                     event.type.value,
                 )
-                msg = f"Error in handler {handler_name} for event type {event.type.value}"
-                raise RouterError(
-                    msg,
-                    event_type=event.type,
-                    handler_name=handler_name,
-                ) from e
+
+        if errors:
+            first_handler_name, first_error = errors[0]
+            if len(errors) == 1:
+                msg = f"Error in handler {first_handler_name} for event type {event.type.value}"
+            else:
+                failed_handlers = ", ".join(name for name, _ in errors)
+                msg = (
+                    f"{len(errors)} handlers failed for event type {event.type.value}: "
+                    f"{failed_handlers}"
+                )
+            raise RouterError(
+                msg,
+                event_type=event.type,
+                handler_name=first_handler_name,
+            ) from first_error
